@@ -30,6 +30,7 @@
 
 #include <config.h>
 
+#include <string.h>
 #include "nautilus-adapter-stream-load-strategy.h"
 
 #include <bonobo/bonobo-stream.h>
@@ -38,6 +39,8 @@
 #include <gtk/gtkobject.h>
 #include <eel/eel-gtk-macros.h>
 #include <libnautilus/nautilus-view.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
+#include <libgnomevfs/gnome-vfs-mime-utils.h>
 
 struct NautilusAdapterStreamLoadStrategyDetails {
 	Bonobo_PersistStream  persist_stream;
@@ -113,6 +116,31 @@ nautilus_adapter_stream_load_strategy_new (Bonobo_PersistStream  persist_stream)
 	return NAUTILUS_ADAPTER_LOAD_STRATEGY (strategy);
 }
 
+static ORBit_IMethod *
+get_stream_load_method (void)
+{
+	guint i;
+	ORBit_IInterface *iface;
+	static ORBit_IMethod *method = NULL;
+	
+	iface = &Bonobo_PersistStream__iinterface;
+	if (!method) {
+		for (i = 0; i < iface->methods._length; i++) {
+			if (!strcmp ("load", iface->methods._buffer [i].name)) {
+				method = &iface->methods._buffer [i];
+			}
+		}
+	}
+	g_assert (method);
+
+	return method;
+}
+
+static void
+unref_stream_cb (gpointer user_data)
+{
+	bonobo_object_release_unref (user_data, NULL);
+}
 
 static void
 nautilus_adapter_stream_load_strategy_load_location (NautilusAdapterLoadStrategy *abstract_strategy,
@@ -122,6 +150,9 @@ nautilus_adapter_stream_load_strategy_load_location (NautilusAdapterLoadStrategy
 	Bonobo_Stream stream;
 	CORBA_Environment ev;
 	char *moniker_str;
+	char *escaped_uri;
+	char *mime_type;
+	gpointer args[2];
 
 	strategy = NAUTILUS_ADAPTER_STREAM_LOAD_STRATEGY (abstract_strategy);
 	g_object_ref (strategy);
@@ -129,39 +160,39 @@ nautilus_adapter_stream_load_strategy_load_location (NautilusAdapterLoadStrategy
 	CORBA_exception_init (&ev);
 
 	nautilus_adapter_load_strategy_report_load_underway (abstract_strategy);
-	
-	moniker_str = g_strconcat ("vfs:", uri, NULL);
+
+	/* We must escape the '!' in the URI here, because it is
+	 * used as argument delimiter within monikers.
+	 */
+	escaped_uri = gnome_vfs_escape_set (uri, "!");
+	moniker_str = g_strconcat ("vfs:", escaped_uri, NULL);
 	stream = bonobo_get_object (moniker_str, "IDL:Bonobo/Stream:1.0", &ev);
 	g_free (moniker_str);
+	g_free (escaped_uri);
 
 	if (BONOBO_EX (&ev) || CORBA_Object_is_nil (stream, &ev)) {
 		nautilus_adapter_load_strategy_report_load_failed (abstract_strategy);
 	} else {
-		/* FIXME bugzilla.gnome.org 41248: 
-		 * Dan Winship points out that we should pass the
-		 * MIME type here to work with new implementers of
-		 * PersistStream that pay attention to the MIME type. It
-		 * doesn't matter right now, but we should fix it
-		 * eventually. Currently, we don't store the MIME type, but
-		 * it should be easy to keep it around and pass it in here.
-		 */
+		/* This adds an extra sniffing, which is a bit of a problem.
+		 * We think this is ok, since it is relatively cheap and
+		 * the adapter isn't used often.  When the adapter is
+		 * moved into the nautilus process, this should use the
+		 * mime type from the NautilusFile. */
+		mime_type = gnome_vfs_get_mime_type (uri);
+		args [0] = &stream;
+		args [1] = &mime_type;
 
-		Bonobo_PersistStream_load
-			(strategy->details->persist_stream,
-			 stream,
-			 "", /* MIME type of stream */
-			 &ev);
+		nautilus_adapter_load_strategy_load_async (
+			abstract_strategy,
+			strategy->details->persist_stream,
+			get_stream_load_method (),
+			args,
+			unref_stream_cb,
+			stream);
 
-		bonobo_object_release_unref (stream, &ev);
-
-		if (ev._major == CORBA_NO_EXCEPTION) {
-			nautilus_adapter_load_strategy_report_load_complete (abstract_strategy);
-		} else {
-			nautilus_adapter_load_strategy_report_load_failed (abstract_strategy);
-		}
+		g_free (mime_type);
         }
 
-
 	g_object_unref (strategy);
 
 	CORBA_exception_free (&ev);
