@@ -56,6 +56,7 @@ static gpointer default_home_location_callback           (void);
 static gpointer default_default_folder_viewer_callback	 (void);
 static void     import_old_preferences_if_needed         (void);
 static gpointer default_home_link_name                   (void);
+static gpointer default_computer_link_name               (void);
 static gpointer default_trash_link_name                  (void);
 
 /* An enumeration used for installing type specific preferences defaults. */
@@ -190,15 +191,6 @@ static EelEnumerationEntry default_icon_view_sort_order_enum_entries[] = {
 	{ NULL }
 };
 
-static EelEnumerationEntry default_list_view_sort_order_enum_entries[] = {
-	{ "name",	       N_("By Name"),		    NAUTILUS_FILE_SORT_BY_DISPLAY_NAME },
-	{ "size",	       N_("By Size"),		    NAUTILUS_FILE_SORT_BY_SIZE },
-	{ "type",	       N_("By Type"),		    NAUTILUS_FILE_SORT_BY_TYPE },
-	{ "modification_date", N_("By Modification Date"),  NAUTILUS_FILE_SORT_BY_MTIME }, 
-	{ "emblems",	       N_("By Emblems"),	    NAUTILUS_FILE_SORT_BY_EMBLEMS },
-	{ NULL }
-};
-
 static EelEnumerationEntry standard_font_size_entries[] = {
 	{ "8",		   N_("8"),	8 },
 	{ "10",		   N_("10"),	10 },
@@ -212,18 +204,11 @@ static EelEnumerationEntry standard_font_size_entries[] = {
 	{ NULL }
 };
 
-static EelEnumerationEntry icon_captions_enum_entries[] = {
-	{ "size",	       N_("size"),		0 },
-	{ "type",	       N_("type"),		1 },
-	{ "date_modified",     N_("date modified"),	2 },
-	{ "date_changed",      N_("date changed"),	3 }, 
-	{ "date_accessed",     N_("date accessed"),	4 }, 
-	{ "owner",	       N_("owner"),		5 }, 
-	{ "group",	       N_("group"),		6 }, 
-	{ "permissions",       N_("permissions"),	7 }, 
-	{ "octal_permissions", N_("octal permissions"),	8 }, 
-	{ "mime_type",	       N_("MIME type"),		9 }, 
-	{ "none",	       N_("none"),		10 }, 
+/* These are not translated, because the text is not used in the ui */
+static EelEnumerationEntry date_format_entries[] = {
+	{ "locale",	   "Locale Default",	NAUTILUS_DATE_FORMAT_LOCALE },
+	{ "iso",	   "ISO Format",	NAUTILUS_DATE_FORMAT_ISO },
+	{ "informal",	   "Informal",		NAUTILUS_DATE_FORMAT_INFORMAL },
 	{ NULL }
 };
 
@@ -235,14 +220,13 @@ static EelEnumerationInfo enumerations[] = {
 	{ "click_policy",		   click_policy_enum_entries },
 	{ "default_folder_viewer",	   default_folder_viewer_enum_entries },
 	{ "default_icon_view_sort_order",  default_icon_view_sort_order_enum_entries },
-	{ "default_list_view_sort_order",  default_list_view_sort_order_enum_entries },
 	{ "default_zoom_level",		   default_zoom_level_enum_entries },
 	{ "executable_text_activation",	   executable_text_activation_enum_entries },
 	{ "file_size",			   file_size_enum_entries },
-	{ "icon_captions",		   icon_captions_enum_entries },
 	{ "search_bar_type",		   search_bar_type_enum_entries },
 	{ "speed_tradeoff",		   speed_tradeoff_enum_entries },
 	{ "standard_font_size",		   standard_font_size_entries },
+	{ "date_format",		   date_format_entries },
 	{ NULL }
 };
 
@@ -397,7 +381,7 @@ static const PreferenceDefault preference_defaults[] = {
 	  PREFERENCE_STRING_LIST,
 	  "size,date_modified,type",
 	  NULL, NULL,
-	  "icon_captions"
+	  NULL
 	},
 	{ NAUTILUS_PREFERENCES_HIDE_BUILT_IN_BOOKMARKS,
 	  PREFERENCE_BOOLEAN,
@@ -408,6 +392,10 @@ static const PreferenceDefault preference_defaults[] = {
 	  PREFERENCE_INTEGER,
 	  GINT_TO_POINTER (148)
 	},
+	{ NAUTILUS_PREFERENCES_ALWAYS_USE_BROWSER,
+	  PREFERENCE_BOOLEAN,
+	  GINT_TO_POINTER (FALSE)
+	},
 	{ NAUTILUS_PREFERENCES_START_WITH_LOCATION_BAR,
 	  PREFERENCE_BOOLEAN,
 	  GINT_TO_POINTER (TRUE)
@@ -424,6 +412,12 @@ static const PreferenceDefault preference_defaults[] = {
 	  PREFERENCE_BOOLEAN,
 	  GINT_TO_POINTER (TRUE)
 	},
+	{ NAUTILUS_PREFERENCES_DATE_FORMAT,
+	  PREFERENCE_STRING,
+	  "locale",
+	  NULL, NULL,
+	  "date_format"
+	},
 
 	/* Home URI */
 	{ NAUTILUS_PREFERENCES_HOME_URI,
@@ -472,7 +466,7 @@ static const PreferenceDefault preference_defaults[] = {
 	  PREFERENCE_STRING,
 	  "name",
 	  NULL, NULL,
-	  "default_list_view_sort_order"
+	  NULL,
 	},
 	{ NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_SORT_IN_REVERSE_ORDER,
 	  PREFERENCE_BOOLEAN,
@@ -488,7 +482,7 @@ static const PreferenceDefault preference_defaults[] = {
 	/* Desktop Preferences */
 	{ NAUTILUS_PREFERENCES_DESKTOP_HOME_VISIBLE,
 	  PREFERENCE_BOOLEAN,
-	  GINT_TO_POINTER (TRUE)
+	  GINT_TO_POINTER (FALSE)
 	},
 	
 	{ NAUTILUS_PREFERENCES_DESKTOP_HOME_NAME,
@@ -497,6 +491,17 @@ static const PreferenceDefault preference_defaults[] = {
 	  default_home_link_name, g_free,
 	},
 	
+	{ NAUTILUS_PREFERENCES_DESKTOP_COMPUTER_VISIBLE,
+	  PREFERENCE_BOOLEAN,
+	  GINT_TO_POINTER (TRUE)
+	},
+	
+	{ NAUTILUS_PREFERENCES_DESKTOP_COMPUTER_NAME,
+	  PREFERENCE_STRING,
+	  NULL,
+	  default_computer_link_name, g_free,
+	},
+	
 	{ NAUTILUS_PREFERENCES_DESKTOP_TRASH_VISIBLE,
 	  PREFERENCE_BOOLEAN,
 	  GINT_TO_POINTER (TRUE)
@@ -508,12 +513,6 @@ static const PreferenceDefault preference_defaults[] = {
 	  default_trash_link_name, g_free,
 	},
 	
-	/* non-visible preferences */
-	{ NAUTILUS_PREFERENCES_ADD_TO_SESSION,
-	  PREFERENCE_BOOLEAN,
-	  GINT_TO_POINTER (TRUE)
-	},
-
 	{ NULL }
 };
 
@@ -531,6 +530,12 @@ default_home_link_name (void)
 	return g_strdup_printf (_("%s's Home"), g_get_user_name ());
 }
 
+static gpointer
+default_computer_link_name (void)
+{
+	return g_strdup (_("Computer"));
+}
+
 static gpointer
 default_trash_link_name (void)
 {
