@@ -30,6 +30,7 @@
 
 
 #include "file-manager/fm-bonobo-provider.h"
+#include "file-manager/fm-ditem-page.h"
 #include "file-manager/fm-desktop-icon-view.h"
 #include "file-manager/fm-icon-view.h"
 #include "file-manager/fm-list-view.h"
@@ -57,6 +58,7 @@
 #include <gdk/gdkx.h>
 #include <gtk/gtkinvisible.h>
 #include <gtk/gtksignal.h>
+#include <gtk/gtkwindow.h>
 #include <libgnome/gnome-config.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnome/gnome-util.h>
@@ -98,7 +100,6 @@ static GList *nautilus_application_window_list;
 /* Keeps track of all the object windows */
 static GList *nautilus_application_spatial_window_list;
 
-static gboolean need_to_show_first_time_druid     (void);
 static void     desktop_changed_callback          (gpointer                  user_data);
 static void     desktop_location_changed_callback (gpointer                  user_data);
 static void     volume_unmounted_callback         (GnomeVFSVolumeMonitor    *monitor,
@@ -181,6 +182,8 @@ nautilus_application_instance_init (NautilusApplication *application)
 	/* Watch for volume unmounts so we can close open windows */
 	g_signal_connect_object (gnome_vfs_get_volume_monitor (), "volume_unmounted",
 				 G_CALLBACK (volume_unmounted_callback), application, 0);
+	g_signal_connect_object (gnome_vfs_get_volume_monitor (), "volume_pre_unmount",
+				 G_CALLBACK (volume_unmounted_callback), application, 0);
 	g_signal_connect_object (gnome_vfs_get_volume_monitor (), "volume_mounted",
 				 G_CALLBACK (volume_mounted_callback), application, 0);
 
@@ -364,36 +367,6 @@ migrate_old_nautilus_files (void)
 	g_free (migrated_file);
 }
 
-static gint
-create_starthere_link_callback (gpointer data)
-{
-	char *desktop_path;
-	char *desktop_link_file;
-	char *cmd;
-	
-	/* Create default services icon on the desktop */
-	desktop_path = nautilus_get_desktop_directory ();
-	desktop_link_file = g_build_filename (desktop_path,
-					      "starthere.desktop",
-					      NULL);
-
-	cmd = g_strconcat ("/bin/cp ",
-			   NAUTILUS_DATADIR,
-			   "/starthere-link.desktop ",
-			   desktop_link_file,
-			   NULL);
-
-	if (system (cmd) != 0) {
-		g_warning ("Failed to execute command '%s'\n", cmd);
-	}
-	
-	g_free (desktop_path);
-	g_free (desktop_link_file);
-	g_free (cmd);
-	
-	return FALSE;
-}
-
 static void
 finish_startup (NautilusApplication *application)
 {
@@ -401,6 +374,7 @@ finish_startup (NautilusApplication *application)
 	nautilus_module_init ();
 
 	nautilus_module_add_type (FM_TYPE_BONOBO_PROVIDER);
+	nautilus_module_add_type (FM_TYPE_DITEM_PAGE);
 	
 	/* initialize the sound machinery */
 	nautilus_sound_init ();
@@ -440,6 +414,14 @@ initialize_kde_trash_hack (void)
 		g_free (kde_conf_file);
 		g_free (key);
 
+		if (kde_trash_dir == NULL) {
+			kde_conf_file = "/usr/share/config/kdeglobals";
+			key = g_strconcat ("=", kde_conf_file, "=/Paths/Trash", NULL);
+			kde_trash_dir = gnome_config_get_string_with_default (key, &def);
+			gnome_config_drop_file (kde_conf_file);
+			g_free (key);
+		}
+
 		if (kde_trash_dir != NULL) {
 			basename = g_path_get_basename (kde_trash_dir);
 			g_free (kde_trash_dir);
@@ -491,16 +473,6 @@ nautilus_application_startup (NautilusApplication *application,
 		return;
 	}
 
-	/* Run the first time startup druid if needed. */
-	if (do_first_time_druid_check && need_to_show_first_time_druid ()) {
-		/* Do this at idle time, once nautilus has initialized
-		 * itself. Otherwise we may spawn a second nautilus
-		 * process when looking for a metadata factory..
-		 */
-		g_idle_add (create_starthere_link_callback, NULL);
-		nautilus_set_first_time_file_flag ();
-	}
-
 	initialize_kde_trash_hack ();
 
 	CORBA_exception_init (&ev);
@@ -831,7 +803,8 @@ nautilus_application_get_existing_spatial_window (const char *location)
 		char *window_location;
 		
 		window_location = nautilus_window_get_location (NAUTILUS_WINDOW (l->data));
-		if (!strcmp (location, window_location)) {
+		if (window_location != NULL &&
+		    strcmp (location, window_location) == 0) {
 			g_free (window_location);
 			return NAUTILUS_SPATIAL_WINDOW (l->data);
 		}
@@ -908,6 +881,25 @@ nautilus_application_close_parent_windows (NautilusSpatialWindow *window)
 	}
 }
 
+void
+nautilus_application_close_all_spatial_windows (void)
+{
+	GList *list_copy;
+	GList *l;
+	
+	list_copy = g_list_copy (nautilus_application_spatial_window_list);
+	for (l = list_copy; l != NULL; l = l->next) {
+		NautilusWindow *window;
+		
+		window = NAUTILUS_WINDOW (l->data);
+		
+		if (NAUTILUS_IS_SPATIAL_WINDOW (window)) {
+			nautilus_window_close (window);
+		}
+	}
+	g_list_free (list_copy);
+}
+
 static void
 nautilus_application_destroyed_window (GtkObject *object, NautilusApplication *application)
 {
@@ -969,8 +961,9 @@ spatial_window_destroyed_callback (void *user_data, GObject *window)
 
 NautilusWindow *
 nautilus_application_present_spatial_window (NautilusApplication *application,
-					    const char          *location,
-					    GdkScreen           *screen)
+					     NautilusWindow      *requesting_window,
+					     const char          *location,
+					     GdkScreen           *screen)
 {
 	NautilusWindow *window;
 	GList *l;
@@ -996,6 +989,29 @@ nautilus_application_present_spatial_window (NautilusApplication *application,
 	}
 
 	window = create_window (application, NAUTILUS_TYPE_SPATIAL_WINDOW, screen);
+	if (requesting_window) {
+		/* Center the window over the requesting window by default */
+		int orig_x, orig_y, orig_width, orig_height;
+		int new_x, new_y, new_width, new_height;
+		
+		gtk_window_get_position (GTK_WINDOW (requesting_window), 
+					 &orig_x, &orig_y);
+		gtk_window_get_size (GTK_WINDOW (requesting_window), 
+				     &orig_width, &orig_height);
+		gtk_window_get_default_size (GTK_WINDOW (window),
+					     &new_width, &new_height);
+		
+		new_x = orig_x + (orig_width - new_width) / 2;
+		new_y = orig_y + (orig_height - new_height) / 2;
+		
+		if (orig_width - new_width < 10) {
+			new_x += 10;
+			new_y += 10;
+		}
+
+		gtk_window_move (GTK_WINDOW (window), new_x, new_y);
+	}
+
 	nautilus_application_spatial_window_list = g_list_prepend (nautilus_application_spatial_window_list, window);
 	g_object_weak_ref (G_OBJECT (window), 
 			   spatial_window_destroyed_callback, NULL);
@@ -1047,51 +1063,6 @@ desktop_changed_callback (gpointer user_data)
 	update_session (gnome_master_client ());
 }
 
-/*
- * need_to_show_first_time_druid
- *
- * Determine whether Nautilus needs to show the first time druid.
- * 
- * Note that the flag file indicating whether the druid has been
- * presented is: ~/.nautilus/first-time-flag.
- *
- * Another alternative could be to use preferences to store this flag
- * However, there because of bug 41229 this is not yet possible.
- *
- * Also, for debugging purposes, it is convenient to have just one file
- * to kill in order to test the startup druid:
- *
- * rm -f ~/.nautilus/first-time-flag
- *
- * In order to accomplish the same thing with preferences, you would have
- * to either kill ALL your preferences or spend time digging in ~/.gconf
- * xml files finding the right one.
- */
-static gboolean
-need_to_show_first_time_druid (void)
-{
-	gboolean result;
-	char *user_directory;
-	char *druid_flag_file_name;
-	
-	user_directory = nautilus_get_user_directory ();
-
-	druid_flag_file_name = g_strconcat (user_directory, "/first-time-flag", NULL);
-	result = !g_file_test (druid_flag_file_name, G_FILE_TEST_EXISTS);
-	g_free (druid_flag_file_name);
-
-	/* we changed the name of the flag for version 1.0, so we should
-	 * check for and delete the old one, if the new one didn't exist 
-	 */
-	if (result) {
-		druid_flag_file_name = g_strconcat (user_directory, "/first-time-wizard-flag", NULL);
-		unlink (druid_flag_file_name);
-		g_free (druid_flag_file_name);
-	}
-	g_free (user_directory); 
-	return result;
-}
-
 static gboolean
 window_can_be_closed (NautilusWindow *window)
 {
@@ -1122,6 +1093,8 @@ volume_mounted_callback (GnomeVFSVolumeMonitor *monitor,
 /* Called whenever a volume is unmounted. Check and see if there are any windows open
  * displaying contents on the volume. If there are, close them.
  * It would also be cool to save open window and position info.
+ *
+ * This is also called on pre_unmount.
  */
 static void
 volume_unmounted_callback (GnomeVFSVolumeMonitor *monitor,
@@ -1130,13 +1103,17 @@ volume_unmounted_callback (GnomeVFSVolumeMonitor *monitor,
 {
 	GList *window_list, *node, *close_list;
 	NautilusWindow *window;
-	char *uri, *activation_uri;
-		
+	char *uri, *activation_uri, *path;
+	GnomeVFSVolumeMonitor *volume_monitor;
+	GnomeVFSVolume *window_volume;
+	
 	close_list = NULL;
 	
 	/* Check and see if any of the open windows are displaying contents from the unmounted volume */
 	window_list = nautilus_application_get_window_list ();
 
+	volume_monitor = gnome_vfs_get_volume_monitor ();
+
 	activation_uri = gnome_vfs_volume_get_activation_uri (volume);
 	/* Construct a list of windows to be closed. Do not add the non-closable windows to the list. */
 	for (node = window_list; node != NULL; node = node->next) {
@@ -1145,6 +1122,18 @@ volume_unmounted_callback (GnomeVFSVolumeMonitor *monitor,
 			uri = nautilus_window_get_location (window);
 			if (eel_str_has_prefix (uri, activation_uri)) {
 				close_list = g_list_prepend (close_list, window);
+			} else {
+				path = gnome_vfs_get_local_path_from_uri (uri);
+				if (path != NULL) {
+					window_volume = gnome_vfs_volume_monitor_get_volume_for_path (volume_monitor,
+												      path);
+					if (window_volume != NULL && window_volume == volume) {
+						close_list = g_list_prepend (close_list, window);
+					}
+					gnome_vfs_volume_unref (window_volume);
+					g_free (path);
+				}
+				
 			}
 			g_free (uri);
 		}
@@ -1222,12 +1211,11 @@ static void
 update_session (gpointer callback_data)
 {
 	set_session_restart (callback_data,
-			     eel_preferences_get_boolean (NAUTILUS_PREFERENCES_ADD_TO_SESSION)
 			     /* Only ever add ourselves to the session
 			      * if we have a desktop window. Prevents the
 			      * session thrashing that's seen otherwise
 			      */
-			     && nautilus_application_desktop_windows != NULL);
+			     nautilus_application_desktop_windows != NULL);
 }
 
 static void
@@ -1243,10 +1231,6 @@ init_session (void)
 	g_signal_connect (client, "die",
 			  G_CALLBACK (removed_from_session), NULL);
 	
-	eel_preferences_add_callback
-		(NAUTILUS_PREFERENCES_ADD_TO_SESSION,
-		 update_session, client);
-
 	update_session (client);
 }
 
